@@ -13,7 +13,7 @@ pub fn format_commit_line(line: &str, highlight_background: bool) -> String {
     let parts = line.split('(').collect::<Vec<_>>();
     if parts.len() == 1 {
         // Just "commit: 123abc", color it all yellow
-        return format!("{}{}{}", header, line, NORMAL);
+        return format!("{header}{line}{NORMAL}");
     }
 
     let commit_part = parts[0].trim();
@@ -21,7 +21,7 @@ pub fn format_commit_line(line: &str, highlight_background: bool) -> String {
     if without_trailing_parenthesis.is_none() {
         // No final parenthesis, this is weird, fall back to showing everything
         // in yellow
-        return format!("{}{}{}", header, line, NORMAL);
+        return format!("{header}{line}{NORMAL}");
     }
 
     let parenthesis_parts = without_trailing_parenthesis
@@ -30,7 +30,7 @@ pub fn format_commit_line(line: &str, highlight_background: bool) -> String {
         .collect_vec();
     let current_branch = compute_current_branch(&parenthesis_parts);
 
-    let comma = format!("{}, ", YELLOW);
+    let comma = format!("{YELLOW}, ");
     return format!(
         "{}{} ({}{}){}",
         header,
@@ -48,26 +48,23 @@ fn format_commit_part(part: &str, current_branch: &Option<String>) -> String {
     if part.starts_with("tag: ") {
         // Implicitly yellow since both the commas and the surrounding
         // parentheses are also yellow.
-        return format!("{}{}{}", BOLD, part, NORMAL_INTENSITY);
+        return format!("{BOLD}{part}{NORMAL_INTENSITY}");
     }
 
     // FIXME: Can we do this with one readable if-statement instead?
     if let Some(current_branch_4_realz) = current_branch {
         if current_branch_4_realz == part {
-            return format!("{}{}{}{}", BOLD, GREEN, part, NORMAL_INTENSITY);
+            return format!("{BOLD}{GREEN}{part}{NORMAL_INTENSITY}");
         }
     }
 
     // Handle "HEAD -> current_branch"
     if let Some(head_branch) = part.strip_prefix("HEAD -> ") {
-        return format!(
-            "{}{}HEAD -> {}{}{}",
-            BOLD, CYAN, GREEN, head_branch, NORMAL_INTENSITY
-        );
+        return format!("{BOLD}{CYAN}HEAD -> {GREEN}{head_branch}{NORMAL_INTENSITY}");
     }
 
     // Assume this is a branch, but not the current one
-    return format!("{}{}{}{}", BOLD, RED, part, NORMAL_INTENSITY);
+    return format!("{BOLD}{RED}{part}{NORMAL_INTENSITY}");
 }
 
 fn compute_current_branch(candidates: &Vec<&str>) -> Option<String> {
